summaryrefslogtreecommitdiffstats
path: root/tdeui/krootpixmap.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdeui/krootpixmap.h')
-rw-r--r--tdeui/krootpixmap.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/tdeui/krootpixmap.h b/tdeui/krootpixmap.h
index 776863c46..8ca135e1f 100644
--- a/tdeui/krootpixmap.h
+++ b/tdeui/krootpixmap.h
@@ -159,16 +159,16 @@ public slots:
* Repaints the widget background. Normally, you shouldn't need this
* as it is handled automatically.
*
* @param force Force a repaint, even if the contents did not change.
*/
- void repaint( bool force );
+ void tqrepaint( bool force );
/**
* Repaints the widget background. Normally, you shouldn't need this
* as it is handled automatically. This is equivalent to calling
- * repaint( false ).
+ * tqrepaint( false ).
*/
- void repaint();
+ void tqrepaint();
/**
* Enables custom handling of the background painting. If custom
@@ -159,16 +159,16 @@ public slots:
* as it is handled automatically.
*
- * @param force Force a repaint, even if the contents did not change.
+ * @param force Force a tqrepaint, even if the contents did not change.
*/